@@ -4,14 +4,22 @@ from .CardToken import CardToken
 from .Payment import Payment
 from .Refund import Refund
 
+
 class DecidirSDK:
-    def __init__(self, merchant):
-        credentials = merchant['credentials']
+    def __init__(self, merchant, merchant_cadena=None):
+        if merchant_cadena:
+            credentials = merchant_cadena['credentials']['decidir']
+            self.payment_type = 'distributed'
+            self.seller_site_id = merchant['credentials']['decidir']['site_id']
+        else:
+            credentials = merchant['credentials']
+            self.payment_type = 'single'
         self.url = 'https://developers.decidir.com/api/v2'
-        self.private_key = credentials['decidir']['access_token']
-        self.public_key = credentials['decidir']['public_key']
+        self.private_key = credentials['access_token']
+        self.public_key = credentials['public_key']
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
+        self.site_id = credentials['site_id']
 
     def customer(self):
         return Customer(self.url, self.private_key, self.public_key)
@@ -23,7 +31,7 @@ class DecidirSDK:
         return CardToken(self.url, self.private_key, self.public_key)
 
     def payment(self):
-        return Payment(self.url, self.private_key, self.public_key)
+        return Payment(self.url, self.private_key, self.public_key, self.payment_type)
 
     def refund(self):
         return Refund(self.url, self.private_key, self.public_key)
